@@ -1,5 +1,7 @@
 import files_sdk.models.account_line_item as account_line_item
 import files_sdk.models.action as action
+import files_sdk.models.action_notification_export as action_notification_export
+import files_sdk.models.action_notification_export_result as action_notification_export_result
 import files_sdk.models.api_key as api_key
 import files_sdk.models.app as app
 import files_sdk.models.as2_key as as2_key
@@ -56,6 +58,7 @@ import files_sdk.models.site as site
 import files_sdk.models.sso_strategy as sso_strategy
 import files_sdk.models.status as status
 import files_sdk.models.style as style
+import files_sdk.models.sync_job as sync_job
 import files_sdk.models.usage_daily_snapshot as usage_daily_snapshot
 import files_sdk.models.usage_snapshot as usage_snapshot
 import files_sdk.models.user as user
@@ -65,6 +68,8 @@ import files_sdk.models.webhook_test as webhook_test
 
 from files_sdk.models.account_line_item import AccountLineItem
 from files_sdk.models.action import Action
+from files_sdk.models.action_notification_export import ActionNotificationExport
+from files_sdk.models.action_notification_export_result import ActionNotificationExportResult
 from files_sdk.models.api_key import ApiKey
 from files_sdk.models.app import App
 from files_sdk.models.as2_key import As2Key
@@ -121,6 +126,7 @@ from files_sdk.models.site import Site
 from files_sdk.models.sso_strategy import SsoStrategy
 from files_sdk.models.status import Status
 from files_sdk.models.style import Style
+from files_sdk.models.sync_job import SyncJob
 from files_sdk.models.usage_daily_snapshot import UsageDailySnapshot
 from files_sdk.models.usage_snapshot import UsageSnapshot
 from files_sdk.models.user import User
