@@ -23,6 +23,7 @@ class Site:
         'color2_text': None,     # string - Page link and button color
         'color2_top': None,     # string - Top bar background color
         'color2_top_text': None,     # string - Top bar text color
+        'contact_name': None,     # string - Site main contact name
         'created_at': None,     # date-time - Time this site was created
         'currency': None,     # string - Preferred currency
         'custom_namespace': None,     # boolean - Is this site using a custom namespace for users?
@@ -70,6 +71,7 @@ class Site:
         'next_billing_amount': None,     # double - Next billing amount
         'next_billing_date': None,     # string - Next billing date
         'office_integration_available': None,     # boolean - Allow users to use Office for the web?
+        'oncehub_link': None,     # string - Link to scheduling a meeting with our Sales team
         'opt_out_global': None,     # boolean - Use servers in the USA only?
         'overage_notified_at': None,     # date-time - Last time the site was notified about an overage
         'overage_notify': None,     # boolean - Notify site email of overages?
